@@ -2,19 +2,23 @@ from ctypes import (c_void_p, c_int, byref, POINTER, c_char_p,
                     c_size_t, c_longlong, c_double)
 from . import LIB
 import numpy
-
-
-def error_handler(filename, methodname, ier):
-    raise RuntimeError(
-        f'ERROR ier={ier} after calling {methodname} in {filename}!'
-        )
+import logging
 
 
 FILE = 'grid.py'
 DOUBLE_ARRAY_PTR = numpy.ctypeslib.ndpointer(dtype=numpy.float64)
 
 
+def error_handler(filename, methodname, ier):
+    msg = f'ier={ier} after calling {methodname} in {filename}!'
+    logging.error(msg)
+    raise RuntimeError(msg)
+
+
 class Grid(object):
+    """
+    A class to represent a collection of quad cells
+    """
 
     def __init__(self):
         """
@@ -97,7 +101,7 @@ class Grid(object):
 
     def setPoints(self, points):
         """
-        Set the points coordinates
+        Set the points coordinates and build the connectivity
 
         :param points: numpy contiguous array of shape (ncells,
                        num_verts_per_cell, 3)
@@ -106,10 +110,12 @@ class Grid(object):
         if ndim != 3:
             raise RuntimeError(f'ERROR: points.shape[2] != 3, got {ndim}!')
         LIB.mnt_grid_setPointsPtr.argtypes = [POINTER(c_void_p),
-                                              c_int, c_longlong,
                                               DOUBLE_ARRAY_PTR]
-        ier = LIB.mnt_grid_setPointsPtr(self.obj, num_verts_per_cell,
-                                        ncells, points)
+        LIB.mnt_grid_build.argtypes = [POINTER(c_void_p), c_int, c_longlong]
+        ier = LIB.mnt_grid_setPointsPtr(self.obj, points)
+        if ier:
+            error_handler(FILE, 'setPointsPtr', ier)
+        ier = LIB.mnt_grid_build(self.obj, num_verts_per_cell, ncells)
         if ier:
             error_handler(FILE, 'setPointsPtr', ier)
 
@@ -160,7 +166,6 @@ class Grid(object):
         if ier:
             error_handler(FILE, 'computeEdgeArcLengths', ier)
 
-
     def getEdgeArcLength(self, cellId, edgeIndex):
         """
         Get the arch length for given cell and edge
@@ -169,14 +174,15 @@ class Grid(object):
         :returns length assuming radius of one
         """
         res = c_double()
-        LIB.mnt_grid_getEdgeArcLength.argtypes = [POINTER(c_void_p), c_longlong, c_int,
+        LIB.mnt_grid_getEdgeArcLength.argtypes = [POINTER(c_void_p),
+                                                  c_longlong, c_int,
                                                   POINTER(c_double)]
-        ier = LIB.mnt_grid_getEdgeArcLength(self.obj, cellId, edgeIndex, byref(res))
+        ier = LIB.mnt_grid_getEdgeArcLength(self.obj, cellId, edgeIndex,
+                                            byref(res))
         if ier:
             error_handler(FILE, 'getEdgeArcLength', ier)
         return res.value
 
-
     def attach(self, varname, data):
         """
         Attach data to the grid.
@@ -184,10 +190,13 @@ class Grid(object):
         :param varname: field name
         :param data: numpy array of size (ncells, nDataPerCell)
         """
-        nDataPerCell = data.shape[-1]
+        nDataPerCell = 1
+        if len(data.shape) > 1:
+            nDataPerCell = data.shape[-1]
         LIB.mnt_grid_attach.argtypes = [POINTER(c_void_p), c_char_p, c_int,
                                         DOUBLE_ARRAY_PTR]
-        # make a copy to ensure that the data exist during the life of this instance
+        # make a copy to ensure that the data exist during the life of
+        # this instance
         self.data[varname] = data.copy()
         ier = LIB.mnt_grid_attach(self.obj, varname.encode('utf-8'),
                                   nDataPerCell, self.data[varname])
